# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SSHKeyAttributes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'fingerprint': 'str',
        'last_login': 'datetime',
        'created': 'datetime'
    }

    attribute_map = {
        'fingerprint': 'fingerprint',
        'last_login': 'lastLogin',
        'created': 'created'
    }

    def __init__(self, fingerprint=None, last_login=None, created=None):  # noqa: E501
        """SSHKeyAttributes - a model defined in Swagger"""  # noqa: E501
        self._fingerprint = None
        self._last_login = None
        self._created = None
        self.discriminator = None
        if fingerprint is not None:
            self.fingerprint = fingerprint
        if last_login is not None:
            self.last_login = last_login
        if created is not None:
            self.created = created

    @property
    def fingerprint(self):
        """Gets the fingerprint of this SSHKeyAttributes.  # noqa: E501

        The Key Fingerprint. The fingerprint can be used to identify and keep track of the key without exposing the actual credential.   # noqa: E501

        :return: The fingerprint of this SSHKeyAttributes.  # noqa: E501
        :rtype: str
        """
        return self._fingerprint

    @fingerprint.setter
    def fingerprint(self, fingerprint):
        """Sets the fingerprint of this SSHKeyAttributes.

        The Key Fingerprint. The fingerprint can be used to identify and keep track of the key without exposing the actual credential.   # noqa: E501

        :param fingerprint: The fingerprint of this SSHKeyAttributes.  # noqa: E501
        :type: str
        """

        self._fingerprint = fingerprint

    @property
    def last_login(self):
        """Gets the last_login of this SSHKeyAttributes.  # noqa: E501

        The date-time the SSH Key was last used to access ExaVault.   # noqa: E501

        :return: The last_login of this SSHKeyAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._last_login

    @last_login.setter
    def last_login(self, last_login):
        """Sets the last_login of this SSHKeyAttributes.

        The date-time the SSH Key was last used to access ExaVault.   # noqa: E501

        :param last_login: The last_login of this SSHKeyAttributes.  # noqa: E501
        :type: datetime
        """

        self._last_login = last_login

    @property
    def created(self):
        """Gets the created of this SSHKeyAttributes.  # noqa: E501

        The date-time the SSH Key was created.  # noqa: E501

        :return: The created of this SSHKeyAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this SSHKeyAttributes.

        The date-time the SSH Key was created.  # noqa: E501

        :param created: The created of this SSHKeyAttributes.  # noqa: E501
        :type: datetime
        """

        self._created = created

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SSHKeyAttributes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SSHKeyAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
