# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WebhookV2EventData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'resources': 'list[WebhookV2EventDataResources]',
        'form_details': 'list[object]',
        'share': 'list[WebhookV2EventDataShare]',
        'transfer_status': 'str'
    }

    attribute_map = {
        'resources': 'resources',
        'form_details': 'formDetails',
        'share': 'share',
        'transfer_status': 'transferStatus'
    }

    def __init__(self, resources=None, form_details=None, share=None, transfer_status=None):  # noqa: E501
        """WebhookV2EventData - a model defined in Swagger"""  # noqa: E501
        self._resources = None
        self._form_details = None
        self._share = None
        self._transfer_status = None
        self.discriminator = None
        if resources is not None:
            self.resources = resources
        if form_details is not None:
            self.form_details = form_details
        if share is not None:
            self.share = share
        if transfer_status is not None:
            self.transfer_status = transfer_status

    @property
    def resources(self):
        """Gets the resources of this WebhookV2EventData.  # noqa: E501


        :return: The resources of this WebhookV2EventData.  # noqa: E501
        :rtype: list[WebhookV2EventDataResources]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this WebhookV2EventData.


        :param resources: The resources of this WebhookV2EventData.  # noqa: E501
        :type: list[WebhookV2EventDataResources]
        """

        self._resources = resources

    @property
    def form_details(self):
        """Gets the form_details of this WebhookV2EventData.  # noqa: E501


        :return: The form_details of this WebhookV2EventData.  # noqa: E501
        :rtype: list[object]
        """
        return self._form_details

    @form_details.setter
    def form_details(self, form_details):
        """Sets the form_details of this WebhookV2EventData.


        :param form_details: The form_details of this WebhookV2EventData.  # noqa: E501
        :type: list[object]
        """

        self._form_details = form_details

    @property
    def share(self):
        """Gets the share of this WebhookV2EventData.  # noqa: E501


        :return: The share of this WebhookV2EventData.  # noqa: E501
        :rtype: list[WebhookV2EventDataShare]
        """
        return self._share

    @share.setter
    def share(self, share):
        """Sets the share of this WebhookV2EventData.


        :param share: The share of this WebhookV2EventData.  # noqa: E501
        :type: list[WebhookV2EventDataShare]
        """

        self._share = share

    @property
    def transfer_status(self):
        """Gets the transfer_status of this WebhookV2EventData.  # noqa: E501

        For uploads, and downloads, whether the file transferred OK. `success` means the transfer did not have errors  # noqa: E501

        :return: The transfer_status of this WebhookV2EventData.  # noqa: E501
        :rtype: str
        """
        return self._transfer_status

    @transfer_status.setter
    def transfer_status(self, transfer_status):
        """Sets the transfer_status of this WebhookV2EventData.

        For uploads, and downloads, whether the file transferred OK. `success` means the transfer did not have errors  # noqa: E501

        :param transfer_status: The transfer_status of this WebhookV2EventData.  # noqa: E501
        :type: str
        """

        self._transfer_status = transfer_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WebhookV2EventData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookV2EventData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
